searchData={"items":[{"type":"module","title":"Exemvi.CRC","doc":"Helper module to calculate the checksum of a QR Code","ref":"Exemvi.CRC.html"},{"type":"function","title":"Exemvi.CRC.checksum_hex/1","doc":"Calculate the checksum of a QR Code\n\nReturns the checksum as a hexadecimal string","ref":"Exemvi.CRC.html#checksum_hex/1"},{"type":"module","title":"Exemvi.QR.MP","doc":"This module contains core functions for Merchant-Presented Mode QR Code","ref":"Exemvi.QR.MP.html"},{"type":"function","title":"Exemvi.QR.MP.parse_to_objects/1","doc":"Parse QR Code into data objects\n\nReturns either:\n- `{:ok, objects}` where `objects` is a list of `Exemvi.MP.Object` structs\n- `{:error, reasons}` where `reasons` is a list of error reasons as atoms","ref":"Exemvi.QR.MP.html#parse_to_objects/1"},{"type":"function","title":"Exemvi.QR.MP.validate_objects/1","doc":"Validate data objects\n\nReturns either:\n- `{:ok, objects}` where `objects` is the objects originally supplied to the function\n- `{:error, reasons}` where `reasons` is a list of validation error reasons as atoms","ref":"Exemvi.QR.MP.html#validate_objects/1"},{"type":"function","title":"Exemvi.QR.MP.validate_qr/1","doc":"Validate whole QR Code\n\nReturns either:\n- `{:ok, qr_code}` where `qr_code` is the QR Code orginally supplied to the function\n- `{:error, reasons}` where `reasons` is a list of validation error reasons as atoms","ref":"Exemvi.QR.MP.html#validate_qr/1"},{"type":"module","title":"Exemvi.QR.MP.Object","doc":"Merchant-Presented Mode data object\n\nProperties:\n- `:id` is a string of data object ID\n- `:value` is a string of data object value. The value is `nil` if the data object is a template\n- `:objects` is a list of data objects in the template. The value is `nil` if the data object is not a template","ref":"Exemvi.QR.MP.Object.html"},{"type":"extras","title":"Exemvi","doc":"# Exemvi\n\nExemvi is a library to work with EMV QR Code Specification for Payment Systems.\n\nExemvi only supports validating and parsing Merchant-Presented Mode (MPM) QR Code. Support for generating MPM QR Code is planned for future versions.\n\nAt this moment, support for Consumer-Presented Mode (CPM) is not planned.\n\nThe specifications of EMV QR Code can be found at https://www.emvco.com/emv-technologies/qrcodes/","ref":"readme.html"},{"type":"extras","title":"Installation - Exemvi","doc":"Add `exemvi` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:exemvi, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - Exemvi","doc":"1. Validating the whole QR Code:\n   ```elixir\n   qr_code = \"qr_code_string\"\n   result = Exemvi.QR.MP.validate_qr(qr_code)\n   ```\n\n   The `result` is either:\n   - `{:ok, qr_code}` where `qr_code` is the QR Code orginally supplied to the function\n   - `{:error, reasons}` where `reasons` is a list of validation error reasons as atoms\n\n2. Parsing QR Code into data objects:\n   ```elixir\n   qr_code = \"qr_code_string\"\n   result = Exemvi.QR.MP.parse_to_objects(qr_code)\n   ```\n\n   The `result` is either:\n   - `{:ok, objects}` where `objects` is a list of `Exemvi.MP.Object` structs\n   - `{:error, reasons}` where `reasons` is a list of parsing error reasons as atoms\n\n3. Validating parsed data objects:\n   ```elixir\n   objects = [%Exemvi.QR.MP.Object{id: \"00\", value: \"01\"}, ...]\n   result = Exemvi.QR.MP.validate_objects(qr_code)\n   ```\n\n   The `result` is either:\n   - `{:ok, objects}` where `objects` is the objects originally supplied to the function\n   - `{:error, reasons}` where `reasons` is a list of validation error reasons as atoms\n\n4. All three functions above can be piped:\n   ```elixir\n   result = qr_code\n            |> Exemvi.QR.MP.validate_qr()\n            |> Exemvi.QR.MP.parse_to_objects()\n            |> Exemvi.QR.MP.validate_objects()\n   ```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Example - Exemvi","doc":"Let's try parsing the official sample.\n\n```elixir\nofficial_sample = \"00020101021229300012D156000000000510A93FO3230Q31280012D15600000001030812345678520441115802CN5914BEST TRANSPORT6007BEIJING64200002ZH0104最佳运输0202北京540523.7253031565502016233030412340603***0708A60086670902ME91320016A0112233449988770708123456786304A13A\"\n\n{:ok, objects} <- Exemvi.QR.MP.parse_to_objects(official_sample)\n```\n\nThe resulting objects looks like below:\n\n```elixir\n[\n  %Exemvi.QR.MP.Object{id: \"00\", objects: nil, value: \"01\"},\n  %Exemvi.QR.MP.Object{id: \"01\", objects: nil, value: \"12\"},\n  %Exemvi.QR.MP.Object{\n    id: \"29\",\n    objects: [\n      %Exemvi.QR.MP.Object{id: \"00\", objects: nil, value: \"D15600000000\"},\n      %Exemvi.QR.MP.Object{id: \"05\", objects: nil, value: \"A93FO3230Q\"}\n    ],\n    value: nil\n  },\n  %Exemvi.QR.MP.Object{\n    id: \"31\",\n    objects: [\n      %Exemvi.QR.MP.Object{id: \"00\", objects: nil, value: \"D15600000001\"},\n      %Exemvi.QR.MP.Object{id: \"03\", objects: nil, value: \"12345678\"}\n    ],\n    value: nil\n  },\n  #... Other objects are removed for brevity\n]\n```\n\nLet's try validating an obviously invalid QR Code.\n\n```elixir\nwrong_qr_code = \"0002XX\"\n{:error, reasons} = Exemvi.QR.MP.validate_qr(wrong_qr_code)\n```\n\nThe resulting error reason is `[:invalid_qr]`. Note that the error is a list containing error atoms.","ref":"readme.html#example"},{"type":"extras","title":"Data Object Names - Exemvi","doc":"When represented as atoms, data object names in this library are formatted in snake case (lower case with underscores). For example `:payload_format_indicator`.\n\n#","ref":"readme.html#data-object-names"},{"type":"extras","title":"Error Values - Exemvi","doc":"The data object naming convention is relevant when figuring out error reason atoms.\n\nBelow are the possible types of failures when validating data objects:\n- Invalid data object value\n\n  The error atom is the snake case object name prefixed with `invalid_`. For example `:invalid_additional_consumer_data_request`\n\n- Missing mandatory data object\n\n  The error atom is the snake case object name prefixed with `missing_`. For example `:missing_country_code`\n\n- Orphaned data object\n\n  The error atom is the snake case object name prefixed with `orphaned_`. For example `:orphaned_value_of_convenience_fee_fixed`","ref":"readme.html#error-values"}],"content_type":"text/markdown"}